#
# spec file for package plasma-framework
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libKF5Plasma5
%define _tar_path 5.102
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           plasma-framework
Version:        5.102.0
Release:        bp156.3.5
Summary:        Plasma library and runtime components based upon KF5 and Qt5
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FIX-UPSTREAM kde#446874
Patch0:         0001-WindowThumbnail-postpone-texture-deletion-to-avoid-c.patch
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libxcb-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  cmake(KF5Activities) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Archive) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Declarative) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5DocTools) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Kirigami2) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Package) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Parts) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Service) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Wayland) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5XmlGui) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Concurrent) >= 5.15.0
BuildRequires:  cmake(Qt5Gui) >= 5.15.0
BuildRequires:  cmake(Qt5Qml) >= 5.15.0
BuildRequires:  cmake(Qt5Quick) >= 5.15.0
BuildRequires:  cmake(Qt5QuickControls2) >= 5.15.0
BuildRequires:  cmake(Qt5Sql) >= 5.15.0
BuildRequires:  cmake(Qt5Svg) >= 5.15.0
BuildRequires:  cmake(Qt5Test) >= 5.15.0
BuildRequires:  cmake(Qt5Widgets) >= 5.15.0
BuildRequires:  cmake(Qt5X11Extras) >= 5.15.0
#FIXME: Figure how to add it properly
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-components = %{version}
Provides:       %{name}-private = %{version}
Obsoletes:      %{name}-private < %{version}
%ifarch %{arm} aarch64
BuildRequires:  pkgconfig(glesv2)
%endif
# Workaround: CMake's OpenGL::EGL target only exists if OpenGL::OpenGL does
BuildRequires:  pkgconfig(gl)

%description
Plasma library and runtime components based upon KF5 and Qt5

%package -n %{lname}
Summary:        Plasma framework - core libraries
Conflicts:      %{name} < 5.49
Conflicts:      %{name}-private < 5.49
Provides:       qt5qmlimport(org.kde.plasma.configuration.2) = 0
Provides:       qt5qmlimport(org.kde.plasma.plasmoid.2) = 0

%description -n %{lname}
This package contains the core libraries needed by the Plasma framework.

%package components
Summary:        Plasma QML components
Requires:       %{name} = %{version}
Requires:       %{name}-private = %{version}
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
%requires_ge    kdeclarative-components

%description components
Plasma QML and runtime components based upon KF5 and Qt5

%package devel
Summary:        Plasma library and runtime components
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       %{name}-components = %{version}
Requires:       %{name}-private = %{version}
Requires:       extra-cmake-modules >= 1.7.0
Requires:       kf5-filesystem
Requires:       cmake(KF5Package) >= %{_kf5_bugfix_version}
Requires:       cmake(KF5Service) >= %{_kf5_bugfix_version}
Requires:       cmake(KF5WindowSystem) >= %{_kf5_bugfix_version}
Requires:       cmake(Qt5Gui) >= 5.15.0
Requires:       cmake(Qt5Qml) >= 5.15.0
Requires:       cmake(Qt5Quick) >= 5.15.0
Conflicts:      kapptemplate <= 15.12.3

%description devel
Plasma library and runtime components based upon KF5 and Qt5

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang %{name} --with-man --all-name

%pre
# Was part of plasma-framework previously, so remove it
if [ $1 -eq 2 ] ; then
  update-alternatives --remove input.svgz \
    %{_datadir}/plasma/desktoptheme/default/icons/input.svgz-kdeorg
fi

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files lang -f %{name}.lang
# LC_SCRIPTS is not recognized by find-lang.sh
%lang(lt) %{_datadir}/locale/lt/LC_SCRIPTS

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Plasma.so.*
%{_kf5_libdir}/libKF5PlasmaQuick.so.*
%{_kf5_debugdir}/plasma-framework.categories
%{_kf5_debugdir}/*.renamecategories

%files
%{_kf5_bindir}/*
%{_kf5_plugindir}/
%{_kf5_plasmadir}/
%{_kf5_servicetypesdir}/
%{_kf5_mandir}/man1/plasmapkg*.*

%files components
%{_kf5_qmldir}/

%files devel
%{_kf5_includedir}/Plasma/
%{_kf5_includedir}/PlasmaQuick/
%{_kf5_includedir}/plasma/
%{_kf5_includedir}/plasmaquick/
%{_kf5_libdir}/cmake/*/
%{_kf5_libdir}/libKF5Plasma.so
%{_kf5_libdir}/libKF5PlasmaQuick.so
%{_kf5_sharedir}/kdevappwizard

%changelog
* Wed Jul 26 2023 Fusion Future <qydwhotmail@gmail.com>
- Add patch to fix crash in task thumbnails (kde#446874)
  * 0001-WindowThumbnail-postpone-texture-deletion-to-avoid-c.patch
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Dialog: Only center panel popup if it still would cover two thirds of its panel widget (kde#462930)
  * containmentinterface: add function to open context menu
  * ExpandableListItem: load custom content when item is expanded
  * PC3/ActionTextField: Specify focus reason for shortcut activation
  * Use StandardKey.Find instead of "CTRL+F"
  * ActionTextField: add property type for focusSequence
  * ActionTextField: show native shortcut text in tooltip
  * ActionTextField: fix StandardKey not working
  * Dialog: Add default case to a switch to make clangd happier
  * Dialog: Use one std::optional instead of two boolean flags
  * Mark transient applets in config (kde#417114)
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Too many changes since 5.100.1, only listing bugfixes:
  * Rework Plasma theme mask corners and outlines (kde#417511)
  * svgitem: do not upscale svg when using fractional scaling (kde#461682)
* Thu Nov 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.1. Hotfix release:
  * svgitem: do not upscale svg when using fractional scaling
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Too many changes since 5.99.0, only listing bugfixes:
  * Never time out tooltip while its control is still hovered (kde#397336)
  * Fix name of margin hints of task manager (kde#456076)
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Revert "Install a plugin for org.kde.plasma.plasmoid"
  * Don't violate the min <= max assert in qBound in Qt 6
  * IconLabel: always enable `fillWidth`
  * wallpaperinterface: allow wallpaper plugin to set custom accent color
  * Add CMake option to build WITHOUT_X11
  * Install a plugin for org.kde.plasma.plasmoid (kde#454062)
  * PC3/IconLabel: Simplify Layout.fillWidth expression for label
  * ExpandableListItem: make fewer assumptions about the action
  * Clear PasswordField with Ctrl+Shift+U (kde#451550)
  * Add fade in and out animations to PC3 ToolTip
  * Reset devicePixelRatio after loading the cachedBackground of mask
  * Always give FrameSvg's mask in logical pixels
  * desktoptheme/breeze: update disk.svg (kde#445810)
  * Remove shortcut to make corona immutable
  * Clean up if statement that is always true
  * Clean up unused code for categories and remove reference in API docs
  * ExpandableListItem: add arrow key navigation support
  * PC3/ProgressBar: Fix sizing bugs, reformat code, remove animation hacks (kde#456550)
  * Port IconItem to use Qt Shader Tools for Qt 6
  * Remove commented out dead slot
  * Keep Tooltips the proper type (kde#446375)
  * don't remove the shadow on ~Dialog (kde#437920)
  * Port away from deprecated QSGSimpleMaterialShader
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Fix dataengine loading in Qt6 code path
  * PC3/Slider: Enable hover events (kde#454714)
  * PlasmaDialog: Don't constantly reset cursor when resizable edges are ON (kde#454714)
  * Add FreeBSD Qt6 CI support
  * PC3: Support RTL layouts in controls
  * extras/ListItem: Fix undefined reference error to properties from newer controls
  * PC3: Improve support for RTL sliders
  * extras/Highlight: Fix code style and explicitness
  * Port from KDeclarative::runtimePlatform to KRuntimePlatform::runtimePlatform
  * BusyIndicator: Fix initialization of the running property
  * extras/ExpandableListItem: Remove 'currentIndex' state when unhovering
  * Doc: Fix typo in a comment
  * Add missing break in switch-case statement
  * PC3/CheckBox: Fix hover animation repeated on press
  * TextField: fix height change when password dot appears
  * Port away from KDeclarative::runtimePlatform
  * ExpandableListItem: add `expanded` property to indicate the view is visible
  * Synchronise busy indicator start points
  * themetest fix a possible memory leak
  * datamodel.cpp 'then' statement is equivalent to the 'else'
  * Fix typo in comment
  * a11y: toolbuttons are pressable
  * a11y: roundbuttons are buttons too
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * docs: clarify URL in IconItem "source" property
  * Update blur and other window effects when the dialog changes size (kde#457053)
  * Fix generated import versions for QtQuick Controls with Qt 6
  * ExpandableListItem: read `Accessible.description` from action
  * ExpandableListItem: give expand button a name and a tooltip
  * ExpandableListItem: add accessible properties
  * PC3/ToolTip: Sync to qq2-desktop-style: Copy delay & timeout implementations
  * PC3/ToolTip: Sync to qq2-desktop-style: Port to QtQuick.Layouts
  * PC3/ToolTip: Sync to qq2-desktop-style: Wrap text on label
  * PlaceholderMessage: use strict Javascript equality
  * Scope DialogShadows lifetime to application (kde#443706)
  * Use non-deprecated URL interceptors access with Qt 6
  * QMenuProxy::transientParent add null checks
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * FrameItemNode: Remove unnecessary attribute
  * Expose the edit mode to the applets
  * Units: Fix sizeForLabels double-scaling icons with Plasma scaling (kde#454131)
  * Remove extra ';'
  * Update plugins.qmltypes for `org.kde.plasma.core`
  * Skip test for old style theme metadata format when building without deprecations
  * Revert "Use QT_FEATURE_foo to detect opengl* support, and TARGET for glesv2"
  * wallpaperinterface: call `setSource` before `setContextProperty`
  * breeze/widgets: Make analog clock follow colorscheme (kde#377935)
- Drop patch. Fixed upstream:
  * 0001-Revert-Use-QT_FEATURE_foo-to-detect-opengl-support-a.patch
* Tue Jun 14 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix window thumbnails on X11:
  * 0001-Revert-Use-QT_FEATURE_foo-to-detect-opengl-support-a.patch
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Too many changes since 5.94.0, only listing bugfixes:
  * Dialog should use the Dock type unless requested otherwise (kde#454635)
  * Add back the WindowsGoBelow panel behavior (kde#455138)
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Too many changes since 5.93.0, only listing bugfixes:
  * Fix use-after-free in ContainmentInterface (kde#451267)
  * Fix osd dialog position (kde#452648)
  * Fix check for argument length in DataEngine loader (kde#452596)
  * Keep PlasmaComponents.Highlight on its former behaviour (kde#452555)
  * Dialog: Do not update layout parameters while hidden (kde#452512)
  * PC3 toggle controls: fix odd heights misaligning indicators (kde#447977)
- Drop upstream patches:
  * b62d83bef7733e4943e6f66787166b41198d1359.patch
  * 0001-Fix-osd-dialog-position.patch
  * 0002-Keep-PlasmaComponents.Highlight-on-its-former-behavi.patch
  * 0003-Fix-check-for-argument-length-in-DataEngine-loader.patch
* Wed Apr 20 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Backport some patches:
  * 0001-Fix-osd-dialog-position.patch (kde#452648)
  * 0002-Keep-PlasmaComponents.Highlight-on-its-former-behavi.patch (kde#452555)
  * 0003-Fix-check-for-argument-length-in-DataEngine-loader.patch (kde#452596)
* Thu Apr 14 2022 Hans-Peter Jansen <hpj@urpla.net>
- Apply b62d83bef7733e4943e6f66787166b41198d1359.patch
  fixes plasmoid layout regression (kde#452512)
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Make WindowThumbnail build against Qt6 as well
  * Plasmacomponents2 Highlight: add explicit id
  * Highlight: change hover: property to hovered:
  * Don't install the heading SVG in breeze-light and breeze-dark Plasma themes
  * AppletInterface: Add `self` property which just returns `this`
  * Allow applets to have empty json metadata & use KPackage's metadata instead
  * Do not compute sizes within dialogs when they're not visible
  * Port dateengine away from inperformant KPluginInfo hack
  * Improve documentation of PlasmaExtras.Highlight
  * Factor out QML module URI string
  * Update documentation regarding PlasmaExtras.Highlight
  * Adapt to the deprecation of qmlRegisterInterface in Qt6
  * Add default switch statement
  * Add power profile icons (kde#449475)
  * Fix Plasmoid attached property look-up on Config objects (kde#451482)
  * Fix potential null parent access
  * Break recursion when checking compact representation
  * Use generic breeze-styled arrow in Plasma style
  * Port to PlasmaExtras version of Highlight
  * Hardcode keyboard shortcut in SearchField for now
  * Add ActionTextField, SearchField, and PasswordField
  * PC3: Remove unreachable code in Svg item from DefaultListItemBackground
  * AppletQuickItem: Ensure we provide the attached property when we have it
  * Port from using plasmoid to Plasmoid
  * Calendar: Draw highlight below the text (kde#451209)
  * Use PACKAGE_CMAKE_INSTALL_PREFIX before any find_dependency() calls
  * Move Highlight from PlasmaComponents 2.0 to PlasmaExtras
  * Introduce PLASMA_NO_CONTEXTPROPERTIES to disable Plasma QML context properties
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * KPluginMetaData::serviceTypes() is gone in KF6
  * Remove or upgrade QQC1 imports from tests where possible
  * Port away from QXcbWindowFunctions for Qt6
  * show the header if both this and dialog background fallback
  * Fix a -Wint-to-void-pointer-cast warning
  * breeze: Clean up SVG Tiny 1.2 errors in button
  * Units: add mediumSpacing
  * Units: update smallSpacing and largeSpacing documentation
  * Use POSITION_INDEPENDENT_CODE for static lib (qt6)
  * Use KConfigPropertyMap instead of KDeclarative::ConfigPropertyMap for KF6
  * Remove the use of the QtQml namespace
  * Adapt to the new location of the Qt namespace meta object in Qt6
  * Adapt to native event filter signature changes in Qt6
  * Adapt to the removed of QtX11Extras in Qt6
  * Adapt to QQuickItem::geometryChanged being renamed in Qt6
  * Port to QRegularExpression
  * Adapt to Qt6 container sizes no longer being a 32bit integer
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Check executables exist in PATH before passing them to QProcess
  * ExpandableListItem: Deprecate custom isEnabled property and alias it to enabled (kde#449539)
  * PC3 ButtonContent: Move property defaultIconSize to the top-level component
  * Identify containments using X-Plasma-ContainmentType instead of service types
  * Native interface always available
  * ModelContextMenu: drop Accessible.role property
  * Do not use Control for PC3::IconLabel (kde#446303)
  * Corona::containmentForScreen: Ignore activities when an empty string is used (kde#448590)
  * Change where add_feature_info(EGL) is called
  * Fix detection of GLX support in QtGui
  * PC3 ScrollView: set step sizes based on devicePixelRatio
  * ConfigModel: Expose Roles enum to QML
  * Use MATCHES (suggested by Samir)
  * Apply patch from Samir
  * Adapt build system for building against qt6 + fix some compile errors
  * Don't fallback to EGL::EGL, just don't link to EGL when it's not found
  * Always sync the setPanelBehavior to wayland (kde#448373)
  * PlasmaQuick::Dialog - Fix flickering issues when resizing (specially in krunner)
  * Always sync the setPanelBehavior to wayland (kde#426969)
  * PC3 ScrollView: Avoid importing QtQuick.Controls.2
  * Doc: Improve descriptions of Plasma::DataSource methods
  * Don't crash when a screen gets disabled and enabled again (kde#447752)
  * PC3 RadioIndicator: use radiobutton.svg for breeze-light and breeze-dark
  * KWayland does not make sense outside of Linux/FreeBSD, so don't try to depend on it there
  * Add Yakuake panel icon (kde#427485)
  * Deprecated PlasmaExtras.ScrollArea component
  * PC3 SwipeView: use longDuration for highlight animation
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * plasmoidheading: make corners consistent, improve top line color
  * Port I18N_NOOP to KLazyLocalizedString
  * PC3 ItemDelegate: Actually use ItemDelegate type
  * Add a destroy method to the view
  * PC3 ProgressBar: fix fill going OOB when indeterminate state ends (kde#428955)
  * Fix background corners and PC3 ToolTip style (kde#442745)
  * fix availableScreenRect for applets/containments (kde#445495)
  * widgets/tasks.svgz: Use more saturated colors for the focus and attention states (kde#434821)
  * Doc: ToolTip: Fix broken example
  * When adding a new applet to a desktop containment, add it to the center
  * DefaultToolTip: Remove unused QML ids
  * DefaultToolTip: Fix whitespace
  * DefaultToolTip: Use strict !== equality
  * DefaultToolTip: Replace spacing expressions with more appropriate ones
  * wallpaperinterface: Update "contextualActions" after clearing actions (kde#446195)
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * wallpaperinterface: Don't double delete action
  * Use `open-menu-symbolic` instead of `application-menu`
  * Make Breeze plasma scrollbar/slider/progressbar color match application theme
  * Heading: Deprecate headerPointSize(int level) method
  * Don't reload renderers for empty paths
  * PageStack: Replace == equality with === strict equality
  * Reload shared renderers when a file changed on disk (kde#445516)
  * PlasmoidHeading: Turn location into an alias for position property
  * Replace variant property type with var and other appropriate types
  * org.kde.plasma.extras: Follow Qt style of implicitWidth/implicitHeight declaration
  * Fix links in generated doc
  * ButtonColumn: Fix missing import
  * Fix IconLabel
  * Title: Replace implementation with Heading {}
  * Title: Lower size (again)
  * QQuickWindow::event after setupwaylandintegration
  * Do updateTheme after QQuickWindow::event (kde#305247)
  * Breeze slider.svg: Fix bad SVG code making shadow invisible
  * set all roles that can be mapped from dialog types to plasma protocol role
  * Forward declare deprecated Plasma::Package class
  * smaller mask to hide glitches
  * Remove dead code
  * KF5PlasmaMacros: Actually install desktop files if they exist
  * Doc: Reflow text
  * make the OSD an actual wayland OSD
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Too many changes since 5.87.0, only listing bugfixes:
  * Fix crash in WindowThumbnail::updatePaintNode() (kde#444015)
  * ExpandableListItem: Finally fix expanded height calculation permanently (kde#443755)
  * Prevent tooltips from being incorrectly dismissed (kde#439522)
  * Split window texture provider from window texture node (kde#439681)
  * breeze: update slider style (kde#355889)
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Too many changes since 5.86.0, only listing bugfixes:
  * Revert "Change busywidget to a gear" (kde#442525)
  * ExpandableListitem: Correct expanded view height calculation (kde#442537)
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * ExpandableListItem: Fix overlapping entries with many expanded items (kde#428102)
  * ExpandableListitem: Fix stylus input for buttons (kde#426079)
  * [Calendar] Fix pinned calendar displaying the wrong number of dots (kde#440627)
  * [PC3/TextField] Fix text color with certain themes (kde#438854)
- Drop upstream patch:
  * 0001-Fix-Plasma-non-Qt-icon-scaling-with-integer-scale-factors.patch
* Tue Aug 17 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to fix a regression in Plasma icon sizes
  when using fractional scaling on X11:
  * 0001-Fix-Plasma-non-Qt-icon-scaling-with-integer-scale-factors.patch
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Too many changes since 5.84.0, only listing bugfixes:
  * Fix Units::roundToIconSize() returning incorrect sizes with non-Qt scaling (kde#390147)
  * Theme::currentThemeHasImage should not return true if parent themes match (kde#439847)
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop patch:
  * 0001-Revert-KF5PlasmaMacros-Only-try-to-install-desktop-f.patch
* Mon Jul 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to revert an upstream change:
  * 0001-Revert-KF5PlasmaMacros-Only-try-to-install-desktop-f.patch
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Too many changes since 5.83.0, only listing bugfixes:
  * Add compatibility code when GLVND is not available (kde#438444)
  * [Calendar] Store plugin manager as QPointer (kde#385011)
  * Connect to global shortcut changes (kde#438662)
  * fix graphics of tooltips (kde#438121)
- Only install the license files once
* Thu Jun 17 2021 Fabian Vogt <fabian@ritter-vogt.de>
- BuildRequire pkgconfig(gl) everywhere to work around oddity in
  FindOpenGL.cmake
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Too many changes since 5.82.0, only listing bugfixes:
  * Fix events appearing in year or decade view (kde#436999)
  * [dataengine] Emit sourceRemoved earlier (kde#436350)
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes since 5.81.0, only listing bugfixes:
  * ContainmentInterface: Set transient parent of submenues (kde#417378)
  * Make the size of the task manager margins as big as the panel
    ones (kde#434324)
  * [Wayland] Ensure pinned popup end up on the panel layer (kde#400317)
  * Fix elide of TabButtons (kde#434945)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Too many changes since 5.80.0, only listing bugfixes:
  * Change ContrastEffect check to AdaptiveTransparency in A.T. check (kde#434200)
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Too many changes since 5.79.0, only listing bugfixes:
  * [plasmacomponents3/TextField|TextArea] Fix placeholder text (kde#433864)
  * [Icon Item] Load .ico files using QIcon (kde#429927)
  * [PC3 ToolTip] Reduce margins to smallSpacing (kde#428191)
  * Revert 4d4db0b1's theme changes (kde#434202)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Too many changes since 5.78.0, only listing bugfixes:
  * widgets>lineedit.svg: fix pixel misalignment woes (kde#432422)
  * Add RESET to globalShortcut property (kde#431006)
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Too many changes since 5.77.0, only listing bugfixes:
  * [PC3 ProgressBar] Set binding for width (kde#430544)
  * Don't allow negative calendar years (kde#430320)
  * Fix broken background (kde#430390)
* Wed Dec 30 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add QML import provides
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Too many changes since 5.76.0, only listing bugfixes:
  * Finish the animation before changing the length of the progressbar highlight (kde#428955)
  * [textfield] Fix clear button overlapping text (kde#429187)
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes since 5.75.0, only listing bugfixes:
  * Always show ExpandableListitem buttons, not just on hover (kde#428624)
  * Lock the header colours of Breeze Dark and Breeze Light (kde#427864)
  * [ExpandableListItem] Make colored text 100%% opaque (kde#427171)
  * ComboBox3.contentItem must be a QQuickTextInput to fix autocomplete (kde#424076)
  * Toggle plasmoids when shortcut is activated (kde#400278)
- Drop upstream patches:
  * 0001-BusyIndicator-Do-not-rotate-when-invisible.patch
  * 0001-Fix-BusyIndicator-rotating-even-when-invisible-again.patch
* Sat Oct 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to avoid 100%% CPU usage by plasmashell:
  * 0001-Fix-BusyIndicator-rotating-even-when-invisible-again.patch
* Thu Oct 15 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to improve krunner responsiveness on wayland (kde#426746):
  * 0001-BusyIndicator-Do-not-rotate-when-invisible.patch
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes since 5.74.0, only listing bugfixes:
  * Fix plasmoidheading.svgz being installed to the wrong place (kde#426537)
  * Make PlasmaComponents3 Tooltips use the typical tooltip style (kde#424506)
  * Fix PC3 Button/ToolButton icons not always having the right color set (kde#426556)
  * Ensure FrameSvg uses lastModified timestamp when using cache (kde#426674)
- Drop upstream patch:
  * 0001-Fix-PC3-Button-ToolButton-icons-not-always-having-th.patch
* Thu Sep 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix PC3 Button icon colors (kde#426556):
  * 0001-Fix-PC3-Button-ToolButton-icons-not-always-having-th.patch
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes since 5.73.0, only listing bugfixes:
  * Fix incorrect default for PlasmaExtras.ListItem (kde#425769)
  * Don't let the background become smaller than the svg (kde#424448)
  * Make PC3 BusyIndicator visuals keep a 1:1 aspect ratio (kde#425504)
  * Unify the flat/normal behavior of PC3 Buttons/ToolButtons (kde#425174)
  * Fix toolbutton-hover margins in button.svg (kde#425255)
  * Fix PC2 ToolButtonStyle margins (kde#425255)
  * Only draw the focus indicator when we got focus via the keyboard (kde#424446)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Too many changes since 5.72.0, only listing bugfixes:
  * Don't show Plasma dialogs in task switchers (kde#419239)
  * Copy DataEngine relays before itterating (kde#422973)
  * Make signal strength in network icons more visible (kde#423843)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Too many changes since 5.71.0, only listing bugfixes:
  * [spinbox] Don't use QQC2 items when we should use PlasmaComponents (kde#423445)
  * Use fully qualified identifiers for metaobject types (kde#423643)
- Drop upstream patches:
  * 0001-Add-property-to-access-the-ExpandableListItem-loader.patch
  * 0001-Introduce-PlaceholderMessage.patch
* Sat Jun 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add new component needed to fix label appearance (kde#422684):
  * 0001-Introduce-PlaceholderMessage.patch
* Thu Jun 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add new API needed by fix for plasma-nm5 (kde#423093):
  * 0001-Add-property-to-access-the-ExpandableListItem-loader.patch
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Too many changes since 5.70.0, only listing bugfixes:
  * Avoid potential disconnect of all signals in IconItem (kde#421170)
- Drop upstream patch:
  * Avoid-potential-disconnect-of-all-signals-in-IconItem.patch
* Thu May 14 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Avoid-potential-disconnect-of-all-signals-in-IconItem.patch
  to fix a possible crash of plasmashell (boo#1171641, kde#421170)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Too many changes since 5.69.0, only listing bugfixes:
  * [PlasmaCore.IconItem] Regression: fix crash on source change (kde#420801)
  * [Plasmoid Heading] Draw the heading only when there is
  an SVG in the theme
  * Fix rounded borders
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Added Page element
  * [pc3/busyindicator] Hide when not running
  * Update window-pin, Add more sizes, Remove redundant edit-delete
  * Make animation durations consistent with Kirigami values
  * WIP: Create a new TopArea element using widgets/toparea svg
  * Added plasmoid heading svg
  * make highlighted property work for roundbutton
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Too many changes since 5.67.0, only listing bugfixes:
  * Try to apply the colorscheme of the current theme to QIcons (kde#417780)
  * Remove hardcoded colors (kde#417511)
  * Construct NullEngine with KPluginMetaData() (kde#417548)
  * Don't warn for invalid plugin metata (kde#412464)
- Drop Try-to-apply-the-colorscheme-of-the-current-theme-to-QIcons.patch
* Mon Mar  2 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patch to fix wrong icon colors with dark desktop
  themes if a fallback icon is used (boo#1157921, kde#417780)
  * Try-to-apply-the-colorscheme-of-the-current-theme-to-QIcons.patch
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Too many changes to list here.
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Too many changes since 5.65.0, only listing bugfixes:
  * Sync QWindow flag WindowDoesNotAcceptFocus to wayland plasmashell interface (kde#415124)
  * [RFC] Fix Display Configuration icon margins (kde#400087)
  * [PC3 ToolButton] Have the label take into account complementary color schemes (kde#414929)
  * Added background colors to active and inactive icon view (kde#370465)
- Drop calendar-Check-out-of-bounds-array-access.patch. Merged upstream
* Mon Dec 30 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add calendar-Check-out-of-bounds-array-access.patch to fix a
  possible crash with a "broken" locale setup (boo#1159871)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Too many changes to list here.
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * map disabledTextColor to ColorScope
  * add DisabledTextColor to Theme
  * [PC3/button] Elide text always
  * Improve panel options menu entries
  * edit mode action
  * Use ECMGenerateExportHeader to manage deprecated API better
  * [icons/media.svg] Add 16 & 32px icons, update style
  * [PlasmaComponents3] Fix checkable toolbutton background
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes since 5.62.0, only listing bugfixes:
  * Fix crash on teardown with Applet's ConfigLoader (kde#411221)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Make notification icons use outline style
  * Skip test on wayland
  * Port trivial connects to the new style
  * make the sizing of the toolbuttons more coherent
  * make button icons follow a reasonable size and layout (kde#399952)
  * Allow applets/containments/wallpaper to defer UIReadyConstraint
  * Make notification icons look like bells
  * Fix incorrect initial tabs position for vertical tab bars (kde#395390)
  * Add missing include
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * [ToolButtonStyle] Use same color group for hovered state
  * Handle colors file in fake plasma theme installer
  * Install plasma theme into local XDG_DATA_DIR for icon test
  * Apply busy indicator duration change of D22646 to the QQC2 style
  * Compile package structure plugins into expected subdirectory
  * Change Highlight to ButtonFocus
  * Make sure we compare paths properly
  * Fix running the dialognativetest without installing
  * Search for the plugin of the other plasmoid
  * [Busy Indicator] Match duration of QQC2-desktop-style version
  * remove dangling remote widgets code
  * Remove deprecated tests
  * Remove hardcoded colors (view.svg, system.svg)
  * Add missing components in org.kde.plasma.components 3.0
  * Update refresh and restart icons to reflect new breeze-icons versions
  * itemMouse isn't defined in plasma.components 3.0
  * use clearItems when an applet gets deleted
  * Fix crash if swtichSize is adjusted during initial setup
  * react when switchWidth/Height changes
  * Remove unused bits in ContainmentAction
  * Improve plugin caching
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Revert-Remove-Qt-version-check.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * [Svg] Fix porting error from QRegExp::exactMatch
  * ContainmentAction: Fix loading from KPlugin
  * regular expression shouldn't be static
  * Better use of Qt APIs in Plasma::Theme
  * [TabBar] Remove exterior margins
  * pluginloader: Change behavior of X-KDE-ParentApp
  * make pinch in calendar work again
  * Add disk-quota icons (kde#403506)
  * Make Plasma::Svg::elementRect a bit leaner
  * Automatically set version of desktopthemes packages to KF5_VERSION
  * Don't notify about changing to the same state it was at
  * Fix the alignment of the label of the toolbutton
  * [PlasmaComponents3] Vertically center button text as well
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Don't modify a temporary object
  * Make Breeze Light/Dark use more system colors
  * Fix warnings
  * Export SortFilterModel sort column to QML
  * plasmacore: fix qmldir, ToolTip.qml no longer part of module
  * signal availableScreenRectChanged for all applets
  * Use simply configure_file to generate the plasmacomponents3 files
  * Update *.qmltypes to current API of QML modules
  * FrameSvg: also clear mask cache on clearCache()
  * FrameSvg: make hasElementPrefix() also handle prefix with trailing -
  * FrameSvgPrivate::generateBackground: generate background also if reqp != p
  * FrameSvgItem: emit maskChanged also from geometryChanged()
  * FrameSvg: prevent crash when calling mask() with no frame yet created
  * FrameSvgItem: emit maskChanged always from doUpdate()
  * API dox: note for FrameSvg::prefix()/actualPrefix() the trailing '-'
  * a kf6 comment
  * Add test for buttons with icon height
  * API dox: point to Plasma5 versions on techbase if avail
  * FrameSvg: l & r borders or t & b don't need to have same height resp. width
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Too many changes to list here
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [AppletInterface] Check for corona before accessing it
  * [Dialog] Don't forward hover event when there is nowhere to forward it to
  * [Menu] Fix triggered signal
  * Reduce the importance of some debug information so actual warnings can be seen.
  * Fix qml warning
  * [PlasmaComponents3 ComboBox] Fix textColor
  * autotests: don't fail if an unrelated window shows up.
  * FrameSvgItem: catch margin changes of FrameSvg also outside own methods
  * Add Theme::blurBehindEnabled()
  * FrameSvgItem: fix textureRect for tiled subitems to not shrink to 0
  * Fix breeze dialog background with Qt 5.12.2 (kde#405548)
  * [Icon Item] Also clear image icon when using Plasma Svg (kde#405298)
  * textfield height based only on clear text (kde#399155)
  * bind alternateBackgroundColor
- Dropped patches, now upstream:
  * 0001-Fix-breeze-dialog-background-with-Qt-5.12.2.patch
* Tue Mar 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to make certain .svgz work with Qt 5.12.2 (kde#405548):
  * 0001-Fix-breeze-dialog-background-with-Qt-5.12.2.patch
* Fri Mar 15 2019 lbeltrame@kde.org
- Update to 5.56.1
  * New bugfix release
- Changes since 5.56.0:
  * Remove crash in plasmashell
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Make it compiles without deprecated method
  * [Icon Item] Block next animation also based on window visibility
  * it's already defined in KDEFrameworkCompilerSettings
  * Show a warning if a plugin requires a newer version
  * Bump the theme versions because icons changed, to invalidate old caches
  * [breeze-icons] Revamp system.svgz
  * Make Breeze theme tooltip texts consistent
  * Change glowbar.svgz to smoother style (kde#391343)
  * Do background contrast fallback at runtime (kde#401142)
  * [breeze desktop theme/dialogs] Add rounded corners to dialogs
  * Fix warning
- Refreshed patches:
  * 0001-Revert-Remove-Qt-version-check.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Revert-Remove-Qt-version-check.patch to revert the commit
  that removes support for Qt < 5.10
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Use more https in links (& update a few urls)
  * [Wallpaper templates] Add missing Comment= entry to desktop file
  * Remove explicit use of ECM_KDE_MODULE_DIR, part of ECM_MODULE_PATH
  * [Plasma Theme] Use new connect syntax
  * Share Plasma::Theme instances between multiple ColorScope
  * Make the clock svg's shadows more logically correct and visually appropriate
  * [frameworks] Do not use light font styles for headings (1/3) (kde#402730)
  * [Dialog] Don't alter mainItem's visibility
  * Reset parentItem when mainItem changes
  * Remove Qt version check
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * [Calendar] Expose firstDayOfWeek in MonthView
  * Add override
  * Add preferences-system-bluetooth-battery to preferences.svgz
  * Fix comparison between signed and unsigned integer warning
  * Fix unused parameter warning
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Remove virtual keyword
  * same behavior as qwidgets comboboxes
  * feature parity of Menu with the Desktop style
  * default values for tooltips
  * make sure flickables are pixelaligned
  * Simplify reference counting of FrameData
  * less spacing
  * ASAN: Fix memory leak in CalendarPlugin
  * ASAN: Fix memory leak in DataSource
  * ASAN: Fix memory leak in Corona
  * ASAN: Fix leak in AppletQuickItem
  * Remove ComponentInstaller
  * Qt 5.9 is now the minimum required version
  * Add back (accidentally?) deleted line in CMakeLists.txt
  * 100%% consistency with kirigami heading sizing
  * more homogeneous look with Kirigami headings
  * install the processed version of private imports
  * Mobile text selection controls
  * Update breeze-light and breeze-dark colorschemes
  * Make sure private header fields are initialized
  * Summary: After this commit https://cgit.kde.org/plasma-framework.git/commit/?id=9f08668147d2e99f8b5069ff50d5c54e672a87af the iconitemtest started to fail, the reason was just a typo in the initial "if" so it does exactly the same in the "if" and the "else" part. So let's correct it to do what it is suposed to do.
  * remove unneeded include
  * Remove qt include prefix
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variables
  * revert icons scaling on mobile
  * Fix minor EBN issues and typos
  * Support mnemonic labels
  * Remove PLASMA_NO_KIO option
  * proper color group for icons
  * center text when no icon
  * smaller dots
  * Reduce double and triple lookups to the frames hash
  * No point in including an empty foreach when NDEBUG isn't defined
  * Properly look for fallback themes
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Bump theme version strings because there are new icons in 5.51
  * add missing PageIndicator
  * better sizing for roundbutton
  * Also raise configuration window when reusing it
  * follow colorscope
  * no hover effects on mobile
  * Revert "add a "preview" file definition for widgetexplorer"
  * slightly translucent when disabled
  * Add missing component: RoundButton
  * add a "preview" file definition for widgetexplorer
  * Remove this line
  * Avoid potential detach on range-loops with non-const Qt containers
  * Combine display OSD icon files and move to plasma icon theme (kde#395714)
  * same fixes as Slider
  * make use of hint-handle-size
  * align the groove in a better way
  * respect color group
  * don't corrupt the active part
  * [Plasma Components 3 Slider] Fix implicit size of handle
  * [Plasma Components 3 ComboBox] Switch entries with mouse wheel
  * Support button icons when present
  * stubs, warning--
  * [Calendar] Wrap day name index around (kde#390330)
  * Fix minor typos
  * [DialogShadows] Use 0 offset for disabled borders on Wayland
- Dropped patches, now upstream:
  * 0001-Support-button-icons-when-present.patch
* Thu Oct 11 2018 fabian@ritter-vogt.de
- Add patch to workaround use of Frameworks 5.51 features in Plasma 5.14:
  * 0001-Support-button-icons-when-present.patch (kde#398626)
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Workaround bug with native rendering and opacity in TextField text (kde#396813)
  * [Icon Item] Watch KIconLoader icon change when using QIcon
  * [Icon Item] Use ItemEnabledHasChanged
  * Get rid of deprecated QWeakPointer usage
  * Fix style sheet for 22-22-system-suspend (kde#397441)
  * Improve Widgets' removal and configure text
  * Copy PlasmaCore binary qmldir file structure into bin for unit tests
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * if an applet is invalid, it has immediately UiReadyConstraint
  * [Plasma PluginLoader] Cache plugins during startup
  * Fix fading node when one textured is atlassed.
  * [Containment] Don't load containment actions with plasma/containment_actions KIOSK restriction
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Use more nullptr
  * FrameSvg: Update mask frame if image path has been changed
  * FrameSvg: Do not wreck shared mask frames
  * FrameSvg: Simplify updateSizes
  * Icons for Keyboard Indicator T9050
  * fix color for media icon
  * FrameSvg: Recache maskFrame if enabledBorders has been changed (kde#382324, kde#390632, kde#391659)
  * FrameSvg: Draw corners only if both borders in both directions are enabled
  * Teach ContainmentInterface::processMimeData how to handle Task Manager drops
  * FrameSVG: Delete redundant checks
  * FrameSVG: Fix QObject include
  * Use QDateTime for interfacing with QML (kde#394423)
- Dropped patches, now upstream:
  * upstream patch use-qdatetime-with-qml.patch
- Remove update-alternatives for input.svgz - not used anymore?
- Fix %%_kf5_bugfix_version
- Merge -private into plasma-framework
- Split off main library as separate package
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
  * Templates: consistent naming, fix translation catalog names & more
  * [Breeze Plasma Theme] Fix kleopatra icon to use color stylesheet (kde#394400)
  * [Dialog] Handle dialog being minimized gracefully (kde#381242)
* Mon Jun  4 2018 lbeltrame@kde.org
- Add upstream patch use-qdatetime-with-qml.patch:
  * Fixes wrong dates being shown in Plasma calendar (kde#394423)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * Dont-alter-memory-management-to-hide-an-item.patch
  * 0001-Revert-windowthumbnail-Use-gamma-correct-scaling.patch
  * 0002-Revert-windowthumbnail-Use-mipmap-texture-filtering.patch
  * Air-Oxygen-themes-Bump-version.patch
* Fri May  4 2018 wbauer@tmo.at
- Remove outdated calendar.svgz from the Air and Oxygen themes to
  fix showing event markers in the calendar (boo#1091832)
- Add Air-Oxygen-themes-Bump-version.patch to raise the version of
  these 2 themes, otherwise Plasma would reuse existing caches
  rendering the above fix ineffective
* Fri May  4 2018 fabian@ritter-vogt.de
- Add patches to fix window thumbnails on Nvidia:
  * 0001-Revert-windowthumbnail-Use-gamma-correct-scaling.patch
  * 0002-Revert-windowthumbnail-Use-mipmap-texture-filtering.patch
* Thu May  3 2018 wbauer@tmo.at
- Add Dont-alter-memory-management-to-hide-an-item.patch to fix a
  possible Plasma crash when changing the desktop layout
  (kde#391642)
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Too many changes to list here
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * use the new value for largeSpacing in Kirigami
  * Reduce visibility of PC3 TextField placeholder text
  * Don't make Titles 20%% transparent either
  * [PackageUrlInterceptor] Don't rewrite "inline"
  * API dox: remove duplicated deprecated comment
  * API dox: Use @deprecated tag for deprecation comment
  * Don't make Headings 20%% transparent, to match Kirigami
  * don't put the fullrep in the popup if not collapsed
  * Remove dead code for finding QCA2, not used since Plasma5
  * Help automoc to find metadata JSON files referenced in the code
  * [AppletQuickItem] Preload applet expander only if not already expanded
  * other preload microoptimizations
  * drop the setting of c++0x
  * Set IconItem default to smooth=true
  * preload the expander (the dialog) too
  * [AppletQuickItem] Fix setting default preload policy if no environment variable is set
  * fix RTL appearance for ComboBox
  * try to preload certain applets in a smart way
  * [Icon Item] Set filtering on FadingNode texture
  * Initialize m_actualGroup to NormalColorGroup
  * Make sure the FrameSvg and Svg instances have the right devicePixelRatio
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Define property in Units.qml for the Plasma styles
  * Include cstdlib for std::free
  * windowthumbnail: Fix the GLXFBConfig selection code
  * Revert "[Plasma Dialog] Call window effects only if visible" (kde#389352)
  * [Default Tooltip] Fix sizing (kde#386260, kde#389371)
  * [Examples] Fix build
  * parametrize qqc2 version
  * don't multiply svg sizes by devicepixelratio
  * [Plasma Dialog] Call window effects only if visible
  * [Plasma Theme] Guard against invalid KPluginInfo object (kde#389152)
  * Fix one source of log spam referenced in Bug 388389 (Empty filename passed to function)
  * [Calendar] Adjust the calendar toolbar anchors
  * API dox: Use code markup for described dataUpdated slot signature
  * [ConfigModel] Set QML context on ConfigModule (kde#388766)
  * [Icon Item] Treat sources starting with a slash as local file
  * fix RTL appearance for ComboBox (kde#387558)
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Const'ify, use nullptr
  * Prevent cmake 3.10+ warning about moc include & Plasma plugin macros
  * [Air theme] Add task bar progress graphic (kde#368215)
  * Templates: remove stray * from license headers
  * make packageurlinterceptor as noop as possible
  * Revert "Don't tear down renderer and other busy work when Svg::setImagePath is invoked with the same arg"
  * move kirigami plasma styles here
  * Add more explicit
  * Use nullptr + add explicit
  * disappearing scrollbars on mobile
  * reuse KPackage instance between PluginLoader and Applet
  * test return value from QTest::qWaitForWindowExposed
  * [AppletQuickItem] Only set QtQuick Controls 1 style once per engine
  * Don't set a window icon in Plasma::Dialog
  * [RTL] - align properly the selected text for RTL (kde#387415)
  * Initialize scale factor to the last scale factor set on any instance
  * Revert "Initialize scale factor to the last scale factor set on any instance"
  * Don't update when the underlying FrameSvg is repaint-blocked
  * Initialize scale factor to the last scale factor set on any instance
  * Move if check inside #ifdef
  * [FrameSvgItem] Don't create unneccessary nodes
  * Don't tear down renderer and other busy work when Svg::setImagePath is invoked with the same arg
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Too many changes to list here
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * manually draw the circle arc
  * [PlasmaComponents Menu] Add ungrabMouseHack
  * [FrameSvg] Optimize updateSizes
  * Don't position a Dialog if it's of type OSD
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Fix org.kde.plasma.calendar with Qt 5.10
  * sceneGraphBackend() is new in Qt 5.9
  * [FrameSvgItem] Iterate child nodes properly
  * pick up the proper positive/neutral/negative colors
  * [Containment Interface] Don't add containment actions to applet actions on desktop
  * Add new component for the greyed out labels in Item Delegates.
  * Fix FrameSVGItem with the software renderer
  * Don't animate IconItem in software mode
  * Fix build without KDocTools
  * remove extra executable bits
  * [FrameSvg] Use new-style connect
  * possibility to set an attached colorscope to not inherit
  * Add extra visual indicator for Checkbox/Radio keyboard focus
  * don't recreate a null pixmap
  * Remove unused functions
  * Pass item to rootObject() since it's now a singleton (kde#384776)
  * Don't list tab names twice
  * don't accept active focus on tab
  * register revision 1 for QQuickItem
  * [Plasma Components 3] Fix RTL in some widgets.
  * Fix invalid id in viewitem.
  * update mail notification icon for better contrast BUG:365297 (kde#365297)
- Dropped patches, now upstream:
  * 0001-Pass-item-to-rootObject-since-it-s-now-a-singleton.patch
* Mon Sep 18 2017 fabian@ritter-vogt.de
- Add patch to fix Plasma Dialogs (kde#384776):
  * 0001-Pass-item-to-rootObject-since-it-s-now-a-singleton.patch
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * [ConfigModel] Guard against adding a null ConfigCategory
  * [ConfigModel] Allow programmatically adding and removing ConfigCategory
  * [EventPluginsManager] Expose pluginPath in model
  * [Icon Item] Don't needlessly unset imagePath
  * [FrameSvg] Use QPixmap::mask() instead of deprecated convoluted way via alphaChannel()
  * [FrameSvgItem] Create margins/fixedMargins object on demand
  * HTML-escape applet name in undo notification
  * fix check state for menu items
  * Force Plasma style for QQC2 in applets
  * Install the PlasmaComponents.3/private folder
  * Guard failed testItem creation
  * [Service] Restore /dev/null usage
  * [Service] Use KConfig::SimpleConfig
  * Drop remains of "locolor" themes
  * Get rid of QSignalMapper
  * [Theme] Use KConfig SimpleConfig
  * Avoid some unnecessary theme content lookups
  * fix check
  * ignore spurious resize events to empty sizes (kde#382340)
- Dropped patches, now upstream:
  * 0001-ignore-spurious-resize-events-to-empty-sizes.patch
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix compilation on Yocto
  * [Containment Interface] always emit contextualActionsAboutToShow for containment
  * add some @deprecated in the documentation
  * remove resourceinstance
  * Treat Button/ToolButton labels as plaintext
  * Don't perform wayland specific fixes when on X (kde#381130)
  * Add KF5WindowSystem to link interface
  * Declare AppManager.js as pragma library
  * [PlasmaComponents] Remove Config.js
  * default to plain text for labels
  * Load translations from KPackage files if bundled (kde#374825)
  * [PlasmaComponents Menu] Don't crash on null action
  * Use new connect syntax in more places
  * [Plasma Dialog] Fix flag conditions
  * update akregator system tray icon BUG: 379861 (kde#379861)
  * [Containment Interface] Keep containment in RequiresAttentionStatus while context menu is open (kde#344205)
  * Revert "Don't list KF5::WindowSystem in public libraries"
  * Don't list KF5::WindowSystem in public libraries
  * API dox: use @param for normal parameter listing, not @arg
  * fix apidocs
  * Fix tab bar layout key handling in RTL (kde#379894)
- Drop 0001-Revert-recreate-plasmashellsurf-on-exposed-destoy-on.patch
  (fixed upstream)
- Add 0001-ignore-spurious-resize-events-to-empty-sizes.patch
* Sat Jul 15 2017 fabian@ritter-vogt.de
- Add patch to revert upstream commit to workaround notifications
  appearing at the wrong location (kde#381130):
  * 0001-Revert-recreate-plasmashellsurf-on-exposed-destoy-on.patch
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Use #if instead of #ifdef
  * Fix the build without wayland/kwayland
  * Make sure size is final after showEvent
  * Fix vlc tray icon margins
  * Fix vlc tray icon color scheme
  * Revert "Make every applet its own focus scope"
  * Set Containments to have focus within the view (kde#381124)
  * generate the old key before updating enabledborders (kde#378508)
  * show show password button also if empty text (kde#378277)
  * Make every applet its own focus scope
  * Emit usedPrefixChanged when prefix is empty
  * don't switch colors on new themes
  * tests: run i18ndcheck only when bash is found
  * Port a bunch of classes away from Plasma::Package
  * cmake: use ecm_add_test more
  * src/plasmaquick/dialog.cpp - fix build without kwayland
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * src/plasmaquick/dialog.cpp - fix build without kwayland
  * Add VLC tray icon
  * Small improvements in IconItem
  * API dox: Use doxygen notation to have comments used
  * API dox: note CamelCase includes by @class tag with more classes
  * API dox: fix doxygen notation with some post-position comments
  * minimize dialog resizes/moves
  * set transientparent for menus
  * Plasmoid templates: use the image which is part of the package (again)
  * Add template for Plasma QML Applet with QML extension
  * [WIP] workarounds for menu positioning
  * recreate plasmashellsurf on exposed, destoy on hidden
  * tests: fix i18ndcheck.sh for paths with special chars
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * reload icon when usesPlasmaTheme changes
  * fix include even if load path isn't set
  * Fix build with CMake 3.8
  * hide scrollbar when useless
  * Install Plasma Components 3 so they can be used
  * Introduce units.iconSizeHints.* to provide user-configurable icon size hints
  * [TextFieldStyle] Fix textField is not defined error
  * Update the ungrabMouse hack for Qt 5.8
  * Guard against Applet not loading AppletInterface (kde#377050)
  * Calendar: Use correct language for month and day names
  * Update qmltypes
  * Generate plugins.qmltypes files for the plugins we install
  * remove some debug
  * if the user did set an implicit size, keep it
- Remove patches, now upstream:
  * keep-implicit-size-if-set.patch
- Remove obsolete patches:
  * loosen-up-kactivities-requirement.patch
- Use %%find_lang %%{name} --with-man --all-name
* Sat Apr 15 2017 lbeltrame@kde.org
- Drop upstreamed patches:
  * 0001-Handle-applyPrefixes-with-an-empty-string.patch
- Add patches from upstream:
  * keep-implicit-size-if-set.patch - Fixes icon size in desktop toolbox
- Update to 5.33.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * [ModelContextMenu] Silence warnings
  * [ModelContextMenu] Use Instantiator instead of Repeater-and-reparent-hack
  * [Calendar] Shrink and elide week names like is done with day delegate
  * [Icon Item] Make "smooth" property actually do something
  * sensible implicit size for svgs
  * [Default Tooltip] Fix icon size
  * fix stylesheet for fcitx.svgz
  * fix typo, iterate all colors available
  * Set implicit size from source size for image/SVG URL sources.
  * add a new property in containment, for an edit mode
  * correct maskRequestedPrefix when no prefix is used
  * [Menu] Harmonize openRelative placement
  * Add KAcceleratorManager
  * Plasma controls based on QtQuickControls2
  * Upgrade KF5 version to 5.33.0.
  * Handle applyPrefixes with an empty string
  * Forward keyPressEvent to super class
  * actually delete old theme caches
  * [Containment Interface] Trigger context menus on pressing "Menu" key
  * [Breeze Plasma Theme] Improve action-overlay icons
  * Port away from setRoleNames where easily possible
  * Use initialiser list
  * Ref/deref DataEngines even if the metadata is invalid
  * Implement FadingMaterial frag/vert shaders on core profile
  * Split frag and vert code of FadingNode into separate files
  * Small cleanups
* Mon Mar 20 2017 fabian@ritter-vogt.de
- Add upstream patch to fix unhovering of desktop items (kde#377441):
  * 0001-Handle-applyPrefixes-with-an-empty-string.patch
  * Workaround already applied to plasma-workspace
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Too many changes to list here
  * Commit translations from l10n-kf5
  * set default hints when repr doesn't export Layout.*
  * possible to set expanded=false for a containment
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * [Menu] Improve available space correction for openRelative
  * move setImagePath logic into updateFrameData()
  * IconItem: Add roundToIconSize property
  * same margins as the normal button
  * [Desktop Themes] Bump version number
  * [SliderStyle] Allow providing a "hint-handle-size" element
  * possibility to use a fallback chain as prefix
  * Make the dataengine alignment timer more precise
  * Connect all connections to action in QMenuItem::setAction
  * [ConfigView] Honor KIOSK Control Module restrictions
  * Fix disabling the spinner animation when Busy indicator has no opacity
  * Fix binding loop regression in FrameSVGItem
  * [FrameSvgItemMargins] Don't update on repaintNeeded
  * IconItemTest: Fix loadPixmap and loadImage tests
  * qml/plasmoid/containmentinterface.cpp - fix compile with Qt5.6
  * [WIP]: integrate drop menu and filecopy drop menu
  * Applet icons for the Plasma Vault
  * fix stylesheet
  * Migrate AppearAnimation and DisappearAnimation to Animators
  * Use QtQuickControls button, instead of PlasmaComponent's
  * Upgrade KF5 version to 5.32.0.
  * Align bottom edge to top edge of visualParent in the TopPosedLeftAlignedPopup case.
  * [ConfigModel] Emit dataChanged when a ConfigCategory changes
  * use anchors instead of fillHeight
  * hardcode padding of scrollview style to 0
  * [ScrollViewStyle] Evaluate frameVisible property
  * don't regenerate frames when setting every property
  * Add kleopatra icon
  * [Button Styles] Use Layout.fillHeight instead of parent.height in a Layout
  * [ContainmentInterface] Also align containment context menu to panel
  * Upgrade Qt5 version requirement to 5.6.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Check for metadata validity in settingsFileChanged (kde#372651)
  * Don't flip tabbar layout if vertical
  * Remove radialGradient4857 (kde#372383)
  * [AppletInterface] Never pull focus away from fullRepresentation
    (kde#372476)
  * Fix SVG icon ID prefix (kde#369622)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
- Drop upstreamed neverpullaway.patch
* Mon Nov 14 2016 fabian@ritter-vogt.de
- Add neverpullaway.patch to fix unfocusing when hiding launcher
  with shortcut (kde#372476)
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * make sure OSD doesn't have Dialog flag (kde#370433)
  * set context proeprties before reloading the qml (kde#371763)
  * Don't reparse the metadata file if it's already loaded
  * Fix crash in qmlplugindump when no QApplication is available
  * Don't show "Alternatives" menu by default
  * New bool to use activated signal as toggle of expanded
    (kde#367685)
  * Fixes for building plasma-framework with Qt 5.5
  * [PluginLoader] Use operator<< for finalArgs instead of
    initializer list
  * use kwayland for shadows and dialog positioning
  * Remaining missing icons and network improvements
  * Move availableScreenRect/Region up to AppletInterface
  * Don't load containment actions for embedded containments
    (system trays)
  * Update applet alternatives menu entry visibility on demand
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
- Drop upstreamed Fixes-for-building-plasma-framework-with-Qt-55.patch,
  0001-make-sure-OSD-doesnt-have-Dialog-flag.patch and
  new-bool-to-use-activated-signal-as-toggle.patch
- Remove network.svgz, latest version is now included in tar
* Wed Nov  2 2016 alarrosa@suse.com
- Add 0001-make-sure-OSD-doesnt-have-Dialog-flag.patch to fix an
  issue by which OSD (like volume changes notifications) were
  not shown when panel was hidden (kde#370433).
* Thu Oct 27 2016 hrvoje.senjan@gmail.com
- Fix SLE build: Fixes-for-building-plasma-framework-with-Qt-55.patch
* Thu Oct 27 2016 fabian@ritter-vogt.de
- Add new-bool-to-use-activated-signal-as-toggle.patch to support
  change in plasma5-desktop to enable closing launchers with Meta
  (kde#367685)
* Fri Oct 14 2016 wbauer@tmo.at
- Update network.svgz to the latest git version to also add the
  "flightmode-on/off" icons to the Air/Oxygen desktop themes
  (boo#999967, kde#368660)
* Thu Oct 13 2016 wbauer@tmo.at
- Add network.svgz from latest upstream git Air desktop theme, this
  includes a lot of network icons that were missing before
  (boo#999967, kde#368660)
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Improve timetracker output
  * [ToolButtonStyle] Fix menu arrow
  * i18n: handle strings in kdevtemplate files
  * i18n: review strings in kdevtemplate files
  * Add removeMenuItem to PlasmaComponents.ContextMenu
  * Update ktorrent icon (kde#369302)
  * [WindowThumbnail] Discard pixmap on map events
  * Don't include kdeglobals when dealing with a cache config
  * Fix Plasma::knownLanguages
  * Resize the view just after setting the containment
  * Avoid creating a KPluginInfo from a KPluginMetaData instance
  * Running tasks must have some indicator
  * Task bar lines according to RR 128802
  * [AppletQuickItem] Break from loop when we found a layout
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop 0001-Commit-translations-from-l10n-kf5.patch, obsorbed by
  5.27.0 tar
* Wed Sep 28 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0~20160928~b115ea1.git
  * Pick up plasma theme to be used with Plasma 5.8
- Cherry pick 0001-Commit-translations-from-l10n-kf5.patch so the
  translations from 5.26.0 are kept (they are only part of tar and
  tag, not in git master)
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Fix device icon 22px icon didn't work in the old file
  * WindowThumbnail: Do GL calls in the correct thread (kde#368066)
  * Make plasma_install_package work with
    KDE_INSTALL_DIRS_NO_DEPRECATED
  * Add margin and padding to the start.svgz icon
  * Fix stylesheet stuff in computer icon
  * Add computer and laptop icon for kicker (kde#367816)
  * Fix cannot assign undefined to double warning in DayDelegate
  * Fix stylesheed svgz files are not in love with me
  * Rename the 22px icons to 22-22-x and the 32px icons to
    x for kicker
  * [PlasmaComponents TextField] Don't bother loading icons
    for unused buttons
  * Extra guard in Containment::corona in the special
    system tray case
  * When marking a containment as deleted, also mark all
    sub-applets as deleted - fixes system tray container configs
    not being deleted
  * Fix Device Notifier icon
  * Add system-search to system in 32 and 22px size
  * Add monochrome icons for kicker
  * Set colour scheme on system-search icon
  * Move system-search into system.svgz
  * Fix wrong or missing "X-KDE-ParentApp" in desktop file definitions
  * Fix API dox of Plasma::PluginLoader: mixup of
    applets/dataengine/services/..
  * Add system-search icon for the sddm theme
  * Add nepomuk 32px icon
  * Update touchpad icon for the system tray
  * Remove code that can never be executed
  * [ContainmentView] Show panels when UI becomes ready
  * Don't redeclare property implicitHeight
  * Use QQuickViewSharedEngine::setTranslationDomain (kde#361513)
  * Add 22px and 32px plasma breeze icon support
  * Remove colored system icons and add 32px monochrome ones
  * Add an optional reveal password button to TextField
  * The standard tooltips are now mirrored when in a
    right-to-left language
  * Performance when changing months in the calendar has
    been greatly improved
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Keep compatiable slot createApplet with Frameworks 5.24
  * Don't delete gl texture twice in thumbnail (kde#365946)
  * Add translation domain to wallpaper QML object
  * Don't manually delete applets
  * Add a kapptemplate for Plasma Wallpaper
  * Templates: register templates in own toplevel category "Plasma/"
  * Templates: Update techbase wiki links in READMEs
  * Define what Plasma packagestructures extend plasmashell
  * Support a size for adding applets
  * Define Plasma PackageStructure as regular
    KPackage PackageStructure plugins
  * Fix: update wallpaper example Autumn's config.qml to QtQuick.Controls
  * Use KPackage to install Plasma Packages
  * If we pass a QIcon as an argument to IconItem::Source, use it
  * Add overlay support to Plasma IconItem
  * Add Qt::Dialog to default flags to make
    QXcbWindow::isTransient() happy (kde#366278)
  * [Breeze Plasma Theme] Add network-flightmode-on/off icons
  * Emit contextualActionsAboutToShow before showing the applet's
    contextualActions menu (kde#366294)
  * [TextField] Bind to TextField length instead of text
  * [Button Styles] Horizontally center in icon-only mode
    (kde#365947)
  * [Containment] Treat HiddenStatus as low status
  * Add kruler system tray icon from Yuri Fabirovsky
  * Fix the infamous 'dialogs show up on the Task Manager'
    bug once more
  * Fix network wireless available icon with an ? emblem
    (kde#355490)
  * IconItem: Use better approach to disable animation when going
    from invisible to visible
  * Set Tooltip window type on ToolTipDialog through KWindowSystem API
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * [Calendar] Flip arrow buttons on right-to-left languages
  * Plasma::Service::operationDescription() should return a QVariantMap
  * Don't include embedded contrainers in containmentAt(pos)
    (kde#361777)
  * Fix the color theming for the restart system icon (login screen)
    (kde#364454)
  * Disable taskbar thumbnails with llvmpipe (kde#363371)
  * Guard against invalid applets (kde#364281)
  * PluginLoader::loadApplet: restore compatibility for
    misinstalled applets
  * Correct folder for PLASMA_PLASMOIDS_PLUGINDIR
  * PluginLoader: improve error message about
    plugin version compatibility
  * Fix check to keep QMenu on screen for multiscreen layouts
  * New containment type for the systray
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Add cantata system tray support (kde#363784)
  * Selected state for Plasma::Svg and IconItem
  * DaysModel: reset m_agendaNeedsUpdate when plugin sends
    new events
  * Update audio and network icon to get a better contrast
    (kde#356082)
  * Deprecate downloadPath(const QString &file)
    in favor of downloadPath()
  * [icon thumbnail] Request for preferred icon size (kde#362324)
  * Plasmoids can now tell whether widgets are locked by
    the user or sysadmin restrictions
  * [ContainmentInterface] Don't try to popup empty QMenu
  * Use SAX for Plasma::Svg stylesheet replacement
  * [DialogShadows] Cache access to QX11Info::display()
  * restore air plasma theme icons from KDE4
  * Reload selected color scheme on colors changed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * [QuickTheme] Fix properties
  * highlight/highlightedText from proper color group
  * ConfigModel: Don't try to resolve empty source path from package
  * [calendar] Only show the events mark on days grid,
    not month or year
  * declarativeimports/core/windowthumbnail.h - fix -Wreorder warning
  * Reload icon theme properly
  * Always write the theme name to plasmarc, also if the
    default theme is chosen
  * [calendar] Add a mark to days containing an event
  * Add Positive, Neutral, Negative text colors
  * ScrollArea: Fix warning when contentItem is not Flickable
  * Add a prop and method for aligning the menu against a corner
    of its visual parent
  * Allow setting minimum width on Menu
  * Maintain order in stored item list
  * Extend API to allow (re)positioning menu items during
    procedural insert
  * Bind highlightedText color in Plasma::Theme
  * Fix unsetting associated application/urls for Plasma::Applets
  * Don't expose symbols of private class DataEngineManager
  * Add an "event" element in the calendar svg
  * SortFilterModel: Invalidate filter when changing filter callback
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * [calendar] Fix calendar applet not clearing selection
    when hiding (kde#360683)
  * update audio icon to use stylesheet
  * update audio mute icon (kde#360953)
  * Fixing the force-creation of applets when plasma is immutable
  * [Fading Node] Don't mix opacity separately (kde#355894)
  * [Svg] Don't reparse configuration in response to
    Theme::applicationPaletteChanged
  * Dialog: Set SkipTaskbar/Pager states before showing window
    (kde#332024)
  * Reintroduce busy property in Applet
  * Make sure PlasmaQuick export file is properly found
  * Don't import an nonexistent layout
  * Make it possible for an applet to offer a test object
  * Replace QMenu::exec with QMenu::popup
  * FrameSvg: Fix dangling pointers in sharedFrames when
    theme changes
  * IconItem: Schedule pixmap update when window changes
  * IconItem: Animate active and enabled change even with
    animations disabled
  * DaysModel: Make update a slot
  * [Icon Item] Don't animate from previous pixmap when it
    has been invisible
  * [Icon Item] Don't call loadPixmap in setColorGroup
  * [Applet] Don't overwrite "Persistent" flag of Undo notification
  * Allowing to override plasma mutability setting on
    containment creation
  * Add icon/titleChanged
  * Remove QtScript dependency
  * Header of plasmaquick_export.h is in plasmaquick folder
  * Install some plasmaquick headers
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Thu Mar 31 2016 hrvoje.senjan@gmail.com
- Conflict with kapptemplate <= 15.12.3 as the Plasma templates
  are removed in newer versions
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * IconItem: Don't overwrite source when using QIcon::name()
  * ContainmentInterface: Fix use of QRect right() and bottom()
  * Remove effectively duplicate code path for handling QPixmaps
  * Add API docs for IconItem
  * Fix stylesheet (kde#359345)
  * Don't wipe window mask on every geometry change when
    compositing is active and no mask has been set
  * Applet: Don't crash on remove panel (kde#345723)
  * Theme: Discard pixmap cache when changing theme (kde#359924)
  * IconItemTest: Skip when grabToImage fails
  * IconItem: Fix changing color of svg icons loaded from icon theme
  * Fix svg iconPath resolving in IconItem
  * If path is passed, pick the tail (kde#359902)
  * Add properties configurationRequired and reason
  * Move contextualActionsAboutToShow to Applet
  * ScrollViewStyle: Do not use margins of the flickable item
  * DataContainer: Fix slot checks before connect/disconnect
  * ToolTip: Prevent multiple geometry changes while changing contents
  * SvgItem: Don't use Plasma::Theme from rendering thread
  * AppletQuickItem: Fix finding own attached layout (kde#358849)
  * Smaller expander for the taskbar
  * ToolTip: Stop show timer if hideTooltip is called (kde#358894)
  * Disable animation of icons in plasma tooltips
  * Drop animations from tooltips
  * Default theme follows color scheme
  * Fix IconItem not loading non-theme icons with name (kde#359388)
  * Prefer other containments than desktop in containmentAt()
  * WindowThumbnail: Discard glx pixmap in stopRedirecting()
    (kde#357895)
  * Remove the legacy applets filter
  * ToolButtonStyle: Don't rely on an outside ID
  * Don't assume we find a corona (kde#359026)
  * Calendar: Add proper back/forward buttons and a "Today" button
    (kde#336124, kde#348362, kde#358536)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
- Drop upstreamed patches:
  0001-Theme-Discard-pixmap-cache-when-changing-theme.patch
  0001-if-path-is-passed-pick-the-tail.patch
  fix-IconItem-regression.patch
  kde357895.patch
- Added loosen-up-kactivities-requirement.patch -- require
  kactivities 5.19.0, as we can't update kactivities5 to 5.20.0
  before Plasma 5.6.0
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Added 0001-Theme-Discard-pixmap-cache-when-changing-theme.patch
  (kde#359924)
* Mon Feb 29 2016 hrvoje.senjan@gmail.com
- Add 0001-if-path-is-passed-pick-the-tail.patch -- fix loading
  of c++ based applets
* Tue Feb 16 2016 hrvoje.senjan@gmail.com
- Added fix-IconItem-regression.patch (kde#359388)
* Sat Feb 13 2016 opensuse.lietuviu.kalba@gmail.com
- Fix regression introduced in KDE Frameworks 5.18 that crash
  KDE Plasma if mouse repeatedly hovers over TaskManager:
  added kde357895.patch (kde#357895)
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Add a property separatorVisible
  * More explicit removal from m_appletInterfaces (kde#358551)
  * Use complementaryColorScheme from KColorScheme
  * AppletQuickItem: Don't try to set initial size bigger than
    parent size (kde#358200)
  * IconItem: Add usesPlasmaTheme property
  * Don't load toolbox on types not desktop or panel
  * IconItem: Try to load QIcon::fromTheme icons as svg (kde#353358)
  * Ignore check if just one part of size is zero in
    compactRepresentationCheck (kde#358039)
  * [Units] Return at least 1ms for durations (kde#357532)
  * Add clearActions() to remove every applet interface action
  * [plasmaquick/dialog] Don't use KWindowEffects for
    Notification window type
  * Deprecate Applet::loadPlasmoid()
  * [PlasmaCore DataModel] Don't reset model when a source is removed
  * Fix margin hints in opague panel background SVG
  * IconItem: Add animated property
  * [Unity] Scale Desktop icon size
  * The button is compose-over-borders
  * PaintedWidth/paintedheight for IconItem
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
- Drop upstreamed compactreprecheck.diff
* Sun Jan 17 2016 hrvoje.senjan@gmail.com
- Unbreak initial layout of the folderview applet:
  added compactreprecheck.diff (kde#358039)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * [ToolButtonStyle] Always indicate activeFocus
  * Use the SkipGrouping flag for the "widget deleted" notification
    (kde#356653)
  * Deal properly with symlinks in path to packages
  * Add HiddenStatus for plasmoid self-hiding
  * Stop redirecting windows when item is disabled or hidden.
    (kde#356938)
  * Don't emit statusChanged if it hasn't changed
  * Fix element ids for east orientation
  * Containment: Don't emit appletCreated with null applet
    (kde#356428)
  * [Containment Interface] Fix erratic high precision scrolling
  * Read KPluginMetada's property X-Plasma-ComponentTypes
    as a stringlist
  * [Window Thumbnails] Don't crash if Composite is disabled
  * Let containments override CompactApplet.qml
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Mon Dec 21 2015 hrvoje.senjan@gmail.com
- Make plasma-framework-devel conflict with kapptemplate
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Add basic plasmoid as example for developerguide
  * Add a couple of plasmoid templates for kapptemplate/kdevelop
  * [calendar] Delay the model reset until the view is ready
    (kde#355943)
  * Don't reposition while hiding. (kde#354352)
  * [IconItem] Don't crash on null KIconLoader theme (kde#355577)
  * Dropping image files onto a panel will no longer offer to set
    them as wallpaper for the panel
  * Dropping a .plasmoid file onto a panel or the desktop will
    install and add it
  * Remove the now unused platformstatus kded module
    (kde#348840)
  * Allow paste on password fields
  * Fix positioning of edit menu, add a button to select
  * [calendar] Use ui language for getting the month name
    (kde#353715)
  * [calendar] Sort the events by their type too
  * [calendar] Move the plugin library to KDeclarative
  * [calendar] qmlRegisterUncreatableType needs a bit
    more arguments
  * Allow adding config categories dynamically
  * [calendar] Move the plugins handling to a separate class
  * Allow plugins to supply event data to Calendar applet
    (kde#349676)
  * Check for slot existence before connecting or disconnecting
    (kde#354751)
  * [plasmaquick] Don't link OpenGL explicitly
  * [plasmaquick] Drop XCB::COMPOSITE and DAMAGE dependency
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Fix TabBar items being cramped together on initial creation,
    which can be observed in eg. Kickoff after Plasma start
  * Fix dropping files onto the desktop/panel not offering a
    selection of actions to take
  * Take QApplication::wheelScrollLines into account from ScrollView
  * Use BypassWindowManagerHint only on platform X11
  * delete old panel background
  * more readable spinner at small sizes
  * colored view-history
  * calendar: Make the entire header area clickable
  * calendar: Don't use current day number in goToMonth
  * calendar: Fix updating decade overview
  * Theme breeze icons when loaded trough IconItem
  * Fix Button minimumWidth property (kde#353584)
  * Introduce appletCreated signal
  * Plasma Breeze Icon: Touchpad add svg id elements
  * Plasma Breeze Icon: change Touchpad to 22x22px size
  * Breeze Icon: add widget icon to notes
  * A script to replace hardcoded colors with stylesheets
  * Apply SkipTaskbar on ExposeEvent
  * Don't set SkipTaskbar on every event
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Make tooltip dialog hidden on the cursor entering the
    inactive ToolTipArea
  * If the desktop file has Icon=/foo.svgz use that file
    from package
  * Add a "screenshot" file type in packages
  * Consider devicepixelration in standalone scrollbar
  * No hover effect on touchscreen+mobile
  * Use lineedit svg margins in sizeHint calculation
  * Don't fade animate icon in plasma tooltips
  * Fix eliding button text
  * Context menus of applets within a panel no longer overlap
    the applet
  * Simplify getting associated apps list in
    AssociatedApplicationManager
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Reparent to flickable if possible
  * Fix package listing
  * Plasma: Fix applet actions might be nullptr (kde#351777)
  * The onClicked signal of PlasmaComponents.ModelContextMenu now
    works properly
  * PlasmaComponents ModelContextMenu can now create Menu sections
  * Port platformstatus kded plugin to json metadata...
  * Handle an invalid metadata in PluginLoader
  * Let the RowLayout figure out the size of the label
  * Always show the edit menu when the cursor is visible
  * Fix loop on ButtonStyle
  * Don't change the flat-iness of a button on pressed
  * On touchscreen and mobile scrollbars are transient
  * Adjust flick velocity&deceleration to dpi
  * Custom cursor delegate only if mobile
  * Touch friendly text cursor
  * Fix parenting and popping up policy
  * Declare __editMenu
  * Add missing cursot handles delegates
  * Rewrite the EditMenu implementation
  * Use the mobile menu only conditionally
  * Reparent the menu to root
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Using a pinch gesture one can now switch between the different
    zoom levels of the calenda
  * comment about code duplication in icondialog
  * Slider groove color was hardcoded, modified to use color scheme
  * Use QBENCHMARK instead of a hard requirement on the machine's
    performance
  * Calendar navigation has been significantly improved, providing
    a year and decade overview
  * PlasmaCore.Dialog now has an 'opacity' property
  * Make some space for the radio button
  * Don't show the circular background if there's a menu
  * Add X-Plasma-NotificationAreaCategory definition
  * Set notifications and osd to show on all desktops
  * Print useful warning when we can not get valid KPluginInfo
  * Fix potential endless recursion in
    PlatformStatus::findLookAndFeelPackage()
  * Rename software-updates.svgz to software.svgz
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
- Drop 0001-Also-check-for-SharedEngineView.patch, merged upstream
* Mon Jul 27 2015 i@marguerite.su
- use update-alternatives for desktoptheme/input.svgz
  to provide space for inputmethods to step in.
- in KDE 4, this icon wasn't held by KDE upstream,
  so many inputmethods use it to integrate monochrome
  systray icons for the DE. Now as it is held and
  reserved, we need to allow inputmethods to override
  it until they find a new solution.
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Make the dark theme completely dark, also the
    complementary group
  * Cache naturalsize separately by scalefactor
  * ContainmentView: Do not crash on an invalid corona metadata
  * AppletQuickItem: Do not access KPluginInfo if not valid
  * Fix occasional empty applet config pages (kde#349250)
  * Improve hidpi support in the Calendar grid component
  * Verify KService has valid plugin info before using it
  * [calendar] Ensure the grid is repainted on theme changes
  * [calendar] Always start counting weeks from Monday
    (kde#349044)
  * [calendar] Repaint the grid when show week numbers
    setting changes
  * An opaque theme is now used when only the blur effect is
    available (kde#348154)
  * Whitelist applets/versions for separate engine
  * Introduce a new class ContainmentView
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
- Added 0001-Also-check-for-SharedEngineView.patch (kde#349172)
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Calendar components can now display week numbers (kde#338195)
  * Use QtRendering for fonts in password fields
  * Fix AssociatedApplicationManager lookup when a mimetype has
    (kde#340326)
  * Fix panel background coloring (kde#347143)
  * Get rid of "Could not load applet" message
  * Capability to load QML kcms in plasmoid config windows
  * Don't use the DataEngineStructure for Applets
  * Port libplasma away from sycoca as much as possible
  * Make SectionScroller follow the ListView.section.criteria
  * Scroll bars no longer automatically hide when a touch
    screen is present (kde#347254)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * PlasmaComponents.Menu now supports sections
  * Use KPluginLoader instead of ksycoca for loading C++ dataengines
  * Consider visualParent rotation in popupPosition (kde#345787)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
- Drop Use-KPluginLoader-to-load-dataengines.patch, merged upstream
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Fixed stray tooltips when temporary owner of tooltip
    disappeared or became empty
  * Fix TabBar not properly laid out initially, which could
    be observed in eg. Kickoff
  * PageStack transitions now use Animators for smoother animations
  * TabGroup transitions now use Animators for smoother animations
  * Make Svg,FrameSvg work qith QT_DEVICE_PIXELRATIO
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Added Use-KPluginLoader-to-load-dataengines.patch from upstream,
  (kde#345209)
* Mon Mar 16 2015 hrvoje.senjan@gmail.com
- Add explicit knotifications-devel BuildRequires
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Fix plasmapkg2 for translated systems
  * Improve tooltip layout
  * Make it possible to let plasmoids to load scripts outside
    the plasma package
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
- Drop guard-around-a-bug-in-older-versions-of-Qt.patch, merged
  upstream
* Tue Feb 17 2015 hrvoje.senjan@gmail.com
- Add guard-around-a-bug-in-older-versions-of-Qt.patch: disable
  use of atlas textures with Qt <= 5.3.2
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Fixed errorneously opening a broken context menu when middle
    clicking Plasma popup
  * Trigger button switch on mouse whee
  * Never resize a dialog bigger than the screen
  * Undelete panels when applet gets undeleted
  * Fixed keyboard shortcuts
  * Restore hint-apply-color-scheme support
  * Reload the configuration when plasmarc changes
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
- Drop patches merged upstream:
  0004-fix-tooltip-positioning.patch,
  0002-reset-the-internal-size-copy-when-the-theme-changes.patch,
  0004-don-t-forward-events-if-not-visible-anymore.patch,
  0005-a-check-more-on-centering.patch
  0003-restore-hint-apply-color-scheme-support.patch,
  0001-Fix-errorneously-opening-a-broken-context-menu-when-.patch,
  0001-collapse-tooltips-that-only-have-text.patch,
  0002-restore-hint-apply-color-scheme-support.patch,
  0001-make-sure-animation-is-disabled-the-first-time.patch,
  0005-Fix-fallback-from-invalid-L-F-packages.patch and
  0003-trigger-button-switch-on-mouse-wheel.patch
* Thu Jan 29 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-collapse-tooltips-that-only-have-text.patch (kde#343390),
  0002-restore-hint-apply-color-scheme-support.patch (kde#343389),
  0003-restore-hint-apply-color-scheme-support.patch (kde#343389),
  0001-make-sure-animation-is-disabled-the-first-time.patch (kde#341933),
  0004-fix-tooltip-positioning.patch and
  0005-Fix-fallback-from-invalid-L-F-packages.patch (kde#343510)
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Fix-errorneously-opening-a-broken-context-menu-when-.patch
  (kde#342702),
  0002-reset-the-internal-size-copy-when-the-theme-changes.patch
  (kde#337704),
  0003-trigger-button-switch-on-mouse-wheel.patch (kde#342778),
  0004-don-t-forward-events-if-not-visible-anymore.patch (kde#342444)
  and 0005-a-check-more-on-centering.patch (kde#342537)
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Let month menu navigate in current year (kde#342327)
  * Expose new OnScreenDisplay window type in Dialog
  * Migrate Plasma::Package to KPackage
  * Fix labels not picking up changes to font settings at runtime
  * Fix text not properly updating its color when switching themes
    (especially dark<-->light)
  * Fix placeholder text in textfields being too strong when
    using a light theme
  * Set visibility on mainItem to match Dialog
  * Load IconItem immediately upon componentComplete()
  * Use the same text colour for comboboxes as buttons
  * Performance improvements (less config-file reparsing, use
    shared config...)
  * roundToIconSize(0) now returns 0
  * Give undo notifications a title
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
- (Build)Require kpackage-devel
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Fix compilation with Qt 5.2.0
  * Fix the platformstatus kded module
  * Migrate BusyIndicator, ProgressBar to QtQuick.Controls
  * Add thumbnailAvailable property to PlasmaCore.WindowThumbnail
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Added kdeclarative-components >= %%{version} Requires to components
  subpackage
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Fix typo in baselibs.conf
* Fri Oct 10 2014 hrvoje.senjan@gmail.com
- Split out the private and components parts of plasma-framework
  as upstream doesn't manage to keep backwards compability. This
  allows updating API/ABI safe libplasma library at the cost of
  hardcoding versions of those private parts in their consumers.
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Drop 18b57ff.patch, merged upstream
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Added 18b57ff.patch: improved Plasma Dialog, and removed duplicated
  code present with Plasma 5.1 release
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 18 2014 hrvoje.senjan@gmail.com
- Adjust BuildRequires depending whether Qt is built with openGL or open GL ES2
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
- Drop 5ab5d89.diff, merged upstream
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Drop kwidgetsaddons-devel BuildRequires
- Added pkgconfig(Qt5Gui) >= 5.2.0, pkgconfig(gl) and pkgconfig(egl)
  BuildRequires (pulled in indirectly, but added in case of future
  split somewhere)
- Only recommend libqt5-qtquickcontrols
- Add baselibs.conf
- Add 5ab5d89.diff, to improve QML translation API
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
- Readjust BuildRequires to latest changes:
  * Drop: kauth-devel, kcrash-devel, kdnssd-framework-devel, kf5umbrella,
    ktexteditor-devel, kwallet-devel, solid-devel, threadweaver-devel
    and pkgconfig(Qt5Declarative)
  * Add: libxcb-devel, pkgconfig(x11), pkgconfig(Qt5Qml) and pkgconfig(Qt5Quick)
* Wed Apr  2 2014 hrvoje.senjan@gmail.com
- Add licenses to doc
- Mark the license as GPL-2.0+ and LGPL-2.0+
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
- Added ktexteditor-devel and kdoctools-devel BuildRequires
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Mon Feb 10 2014 hrvoje.senjan@gmail.com
- Init plasma-framework package
